library(testthat)
library(Quandl)

# test_package("Quandl")